InputItem

Trait InputItem 

pub trait InputItem
where Self: Sized,
{ // Required method fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>; }
Trait implemented for all types that can be parsed from an input line.

Required Methods

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Take parts from the iterator and try to parse them into Self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl InputItem for ()

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for bool

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for char

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for f32

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for f64

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for i8

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for i16

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for i32

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for i64

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for i128

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for isize

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for u8

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for u16

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for u32

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for u64

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for u128

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl InputItem for usize

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<'a> InputItem for &'a str

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem, W: InputItem, Y: InputItem, Z: InputItem, T1: InputItem, T2: InputItem, T3: InputItem, T4: InputItem, T5: InputItem, T6: InputItem> InputItem for (T, U, V, W, Y, Z, T1, T2, T3, T4, T5, T6)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem, W: InputItem, Y: InputItem, Z: InputItem, T1: InputItem, T2: InputItem, T3: InputItem, T4: InputItem, T5: InputItem> InputItem for (T, U, V, W, Y, Z, T1, T2, T3, T4, T5)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem, W: InputItem, Y: InputItem, Z: InputItem, T1: InputItem, T2: InputItem, T3: InputItem, T4: InputItem> InputItem for (T, U, V, W, Y, Z, T1, T2, T3, T4)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem, W: InputItem, Y: InputItem, Z: InputItem, T1: InputItem, T2: InputItem, T3: InputItem> InputItem for (T, U, V, W, Y, Z, T1, T2, T3)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem, W: InputItem, Y: InputItem, Z: InputItem, T1: InputItem, T2: InputItem> InputItem for (T, U, V, W, Y, Z, T1, T2)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem, W: InputItem, Y: InputItem, Z: InputItem, T1: InputItem> InputItem for (T, U, V, W, Y, Z, T1)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem, W: InputItem, Y: InputItem, Z: InputItem> InputItem for (T, U, V, W, Y, Z)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem, W: InputItem, Y: InputItem> InputItem for (T, U, V, W, Y)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem, W: InputItem> InputItem for (T, U, V, W)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem, V: InputItem> InputItem for (T, U, V)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem, U: InputItem> InputItem for (T, U)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for (T,)

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for Option<T>

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for [T; 1]

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for [T; 2]

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for [T; 3]

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for [T; 4]

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for [T; 5]

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for [T; 6]

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for [T; 7]

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for [T; 8]

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T: InputItem> InputItem for [T; 9]

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Source

impl<T> InputItem for Vec<T>
where T: InputItem,

Source

fn read_part(tok: &mut impl Iterator<Item = &'static str>) -> Option<Self>

Implementors